rm(list=ls())

#data importation
setwd("D:/DataMining/Databases_for_mining/dataset_for_soft_dev_and_comparison/revolution r community")
system.time(wave <- read.table(file="wavebin.txt",sep="\t",dec=".",header=T))

#select the 21 first columns for the pca analyses
wave.subset <- subset(wave, select = 1:21)

#package for lda
library(MASS)

#package for rpart
library(rpart)

benchmark <- function(){

  tps <- numeric(8)

  #logistic regression
  a <- system.time(model.glm <- glm(y ~ ., data = wave, family=binomial()))
  tps[1] <- a["elapsed"]
  #print(model.glm)
  a <- system.time(predict(model.glm, newdata = wave, type = "response"))
  tps[2] <- a["elapsed"]

  #linear discriminant analysis
  a <- system.time(model.lda <- lda(y ~ ., data = wave))
  tps[3] <- a["elapsed"]
  #print(model.lda)
  a <- system.time(predict(model.lda, newdata = wave))
  tps[4] <- a["elapsed"]

  #decision tree induction
  a <- system.time(model.rpart <- rpart(y ~ ., data = wave))
  tps[5] <- a["elapsed"]
  #print(model.rpart)
  a <- system.time(predict(model.rpart, newdata = wave, type = "class"))
  tps[6] <- a["elapsed"]

  #principal component analysis (using eigen)
  a <- system.time(pca.princomp <- princomp(wave.subset, cor = T))
  tps[7] <- a["elapsed"]
  #print(pca.princomp)

  #principal component analysis (using singular value decomposition)
  a <- system.time(pca.prcomp <- prcomp(wave.subset, center = T, scale = T))
  tps[8] <- a["elapsed"]
  #print(pca.prcomp)
  
  #return the vector
  return(tps)
}

#repeat 10 times the computation time measurement
m <- replicate(1,benchmark())
print(m)

#mean and median
print(apply(m,1,mean))
print(apply(m,1,median))

